@@ -496,7 +496,7 @@ int main(int argc, char **argv, char **envp)
 		if (fd < 0) {
 		    switch (errno) {
 		    case EINTR:
-            signals_poll();
+			signals_poll();
 		    case ENETDOWN:
 #ifdef EPROTO
 		    case EPROTO:
@@ -509,6 +509,7 @@ int main(int argc, char **argv, char **envp)
 		    case EHOSTUNREACH:
 		    case EOPNOTSUPP:
 		    case ENETUNREACH:
+		    case ECONNABORTED:
 		    case EAGAIN:
 			break;
 
@@ -576,45 +577,7 @@ int main(int argc, char **argv, char **envp)
 		continue;
 	    }
 
-	    /* turn on TCP keepalive if set */
-	    if (config_getswitch(IMAPOPT_TCP_KEEPALIVE)) {
-		int r;
-		int optval = 1;
-		socklen_t optlen = sizeof(optval);
-		struct protoent *proto = getprotobyname("TCP");
-
-		r = setsockopt(fd, SOL_SOCKET, SO_KEEPALIVE, &optval, optlen);
-		if (r < 0) {
-		    syslog(LOG_ERR, "unable to setsocketopt(SO_KEEPALIVE): %m");
-		}
-#ifdef TCP_KEEPCNT
-		optval = config_getint(IMAPOPT_TCP_KEEPALIVE_CNT);
-		if (optval) {
-		    r = setsockopt(fd, proto->p_proto, TCP_KEEPCNT, &optval, optlen);
-		    if (r < 0) {
-			syslog(LOG_ERR, "unable to setsocketopt(TCP_KEEPCNT): %m");
-		    }
-		}
-#endif
-#ifdef TCP_KEEPIDLE
-		optval = config_getint(IMAPOPT_TCP_KEEPALIVE_IDLE);
-		if (optval) {
-		    r = setsockopt(fd, proto->p_proto, TCP_KEEPIDLE, &optval, optlen);
-		    if (r < 0) {
-			syslog(LOG_ERR, "unable to setsocketopt(TCP_KEEPIDLE): %m");
-		    }
-		}
-#endif
-#ifdef TCP_KEEPINTVL
-		optval = config_getint(IMAPOPT_TCP_KEEPALIVE_INTVL);
-		if (optval) {
-		    r = setsockopt(fd, proto->p_proto, TCP_KEEPINTVL, &optval, optlen);
-		    if (r < 0) {
-			syslog(LOG_ERR, "unable to setsocketopt(TCP_KEEPINTVL): %m");
-		    }
-		}
-#endif
-	    }
+	    tcp_enable_keepalive(fd);
 	}
 
 	notify_master(STATUS_FD, MASTER_SERVICE_UNAVAILABLE);
